<?php
namespace Bushelpowered\Api\Statement;

use \Bushelpowered\Api\Statement\V1\Request\GetAllStatementsRequest;
use \Bushelpowered\Api\Statement\V1\Response\StatementListResponse;
use \Bushelpowered\Api\Common\BadRequest;
use \Bushelpowered\Api\Common\NotAuthenticated;
use \Bushelpowered\Api\Common\NotAuthorized;
use \Bidl\Php\Core\Builtins\UnknownError;

class GetAllStatements 
{
    public function __construct(public \Bidl\Php\Core\BidlClient $client)
    {
    }
    
    public function call(GetAllStatementsRequest $request, $headers): StatementListResponse | BadRequest | NotAuthenticated | NotAuthorized | UnknownError
    {
         return $this->client->call('api/statement/GetAllStatements', $request, $this->getWrapper(), $headers);
    }
    
    private function getWrapper() {
        return new class () implements \Bidl\Php\Core\BidlResponse {

            /** @var StatementListResponse | BadRequest | NotAuthenticated | NotAuthorized | UnknownError */
            public $response;
        
            public function __construct()
            {
                $this->mapper = new \JsonMapper();
            }
            
            public function fromJson($data) 
            {
                switch($data->type) {
                  case 'api.statement#GetAllStatementsSuccess':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Statement\V1\Response\StatementListResponse::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#BadRequest':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\BadRequest::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#NotAuthenticated':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\NotAuthenticated::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#NotAuthorized':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\NotAuthorized::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                   default: 
                     $this->response = new \Bidl\Php\Core\Builtins\UnknownError('The response was not a valid bidl response.');
                }
            }
        };
    }
}